get_description: Utility tools to get specimen description and images from...

Description Usage Arguments Examples

Description

Utility tools to get specimen description and images from NYBG's virtual herbarium

Usage

1

Arguments

ny_id

The NYBG specimen ID. It is equivalent to the field catalogNumber in GBIF.

path

Where to save downloaded images. Defaults to getwd().

...

Other parameters passed on to rgbif::occ_search.

Examples

1
2
3
4
5
6
7
8
9
## Not run: 
get_description(1889108)
get_specimen_url(1889108)
fill_description(1889108)
get_image_url(1889108)
open_image(1889108)
download_image(1889108)

## End(Not run)

gustavobio/rnybg documentation built on May 17, 2019, 9:28 a.m.